Class: Google::Cloud::Datastore::V1::TransactionOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Datastore::V1::TransactionOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/datastore/v1/datastore.rb
Overview
Options for beginning a new transaction.
Transactions can be created explicitly with calls to Datastore.BeginTransaction or implicitly by setting ReadOptions.new_transaction in read requests.
Defined Under Namespace
Instance Attribute Summary collapse
-
#read_only ⇒ ::Google::Cloud::Datastore::V1::TransactionOptions::ReadOnly
The transaction should only allow reads.
-
#read_write ⇒ ::Google::Cloud::Datastore::V1::TransactionOptions::ReadWrite
The transaction should allow both reads and writes.
Instance Attribute Details
#read_only ⇒ ::Google::Cloud::Datastore::V1::TransactionOptions::ReadOnly
Returns The transaction should only allow reads.
Note: The following fields are mutually exclusive: read_only, read_write. If a field in that set is populated, all other fields in the set will automatically be cleared.
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'proto_docs/google/datastore/v1/datastore.rb', line 758 class TransactionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options specific to read / write transactions. # @!attribute [rw] previous_transaction # @return [::String] # The transaction identifier of the transaction being retried. class ReadWrite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options specific to read-only transactions. # @!attribute [rw] read_time # @return [::Google::Protobuf::Timestamp] # Reads entities at the given time. # # This must be a microsecond precision timestamp within the past one hour, # or if Point-in-Time Recovery is enabled, can additionally be a whole # minute timestamp within the past 7 days. class ReadOnly include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#read_write ⇒ ::Google::Cloud::Datastore::V1::TransactionOptions::ReadWrite
Returns The transaction should allow both reads and writes.
Note: The following fields are mutually exclusive: read_write, read_only. If a field in that set is populated, all other fields in the set will automatically be cleared.
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'proto_docs/google/datastore/v1/datastore.rb', line 758 class TransactionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options specific to read / write transactions. # @!attribute [rw] previous_transaction # @return [::String] # The transaction identifier of the transaction being retried. class ReadWrite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options specific to read-only transactions. # @!attribute [rw] read_time # @return [::Google::Protobuf::Timestamp] # Reads entities at the given time. # # This must be a microsecond precision timestamp within the past one hour, # or if Point-in-Time Recovery is enabled, can additionally be a whole # minute timestamp within the past 7 days. class ReadOnly include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |